@@ -5,6 +5,9 @@ use swc_common::{ast_node, EqIgnoreSpan, Span};
 
 #[ast_node]
 pub enum Value {
+    #[tag("SquareBracketBlock")]
+    SquareBracketBlock(SquareBracketBlock),
+
     #[tag("ParenValue")]
     Paren(ParenValue),
 
@@ -32,9 +35,6 @@ pub enum Value {
     #[tag("BinValue")]
     Bin(BinValue),
 
-    #[tag("ArrayValue")]
-    Array(ArrayValue),
-
     #[tag("SpaceValues")]
     Space(SpaceValues),
 
@@ -99,13 +99,11 @@ pub struct ParenValue {
     pub value: Option<Box<Value>>,
 }
 
-#[ast_node("ArrayValue")]
-pub struct ArrayValue {
+#[ast_node("SquareBracketBlock")]
+pub struct SquareBracketBlock {
     /// Includes `[` and `]`.
     pub span: Span,
-
-    /// Comma separated list of values.
-    pub values: Vec<Value>,
+    pub children: Option<Vec<Value>>,
 }
 
 #[ast_node("HashValue")]
